==> nsis20b4_0511.zip: nsis/Contrib/Makensisw/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by resource.rc
//
#define DLG_MAIN                        101
#define IDI_ICON                        102
#define DLG_ABOUT                       103
#define IDM_MENU                        104
#define IDK_ACCEL                       105
#define IDI_SHELL                       112
#define IDB_LOGO                        115
#define DLG_DEFINES                     116
#define IDC_LOGWIN                      402
#define IDC_VERSION                     405
#define IDC_CLOSE                       406
#define IDM_ABOUT                       501
#define IDM_EXIT                        502
#define IDM_SAVE                        503
#define IDM_COPY                        504
#define IDM_COPYSELECTED                505
#define IDM_RECOMPILE                   506
#define IDM_NSISHOME                    507
#define IDC_TEST                        1000
#define IDC_ABOUTVERSION                1001
#define IDC_ABOUTCOPY                   1003
#define IDC_ABOUTPORTIONS               1005
#define IDC_CONTRIB                     1009
#define IDC_NSISVER                     1010
#define IDC_OTHERCONTRIB                1016
#define IDC_SYMBOL                      1017
#define IDC_VALUE                       1018
#define IDRIGHT                         1019
#define IDLEFT                          1020
#define IDC_DEFINES                     1021
#define IDM_TEST                        40002
#define IDM_EDITSCRIPT                  40003
#define IDM_DOCS                        40004
#define IDM_LOADSCRIPT                  40005
#define IDM_FIND                        40006
#define IDM_SELECTALL                   40007
#define IDM_CLEARLOG                    40009
#define IDM_BROWSESCR                   40013
#define IDM_NSISDEV                     40014
#define IDM_FORUM                       40016
#define IDM_DEFINES                     40017

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        117
#define _APS_NEXT_COMMAND_VALUE         40018
#define _APS_NEXT_CONTROL_VALUE         1023
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> nsis20b4_0530.zip: nsis/Contrib/Makensisw/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by resource.rc
//
#define IDS_LOADSCRIPT                  1
#define IDS_SAVE                        2
#define IDS_EXIT                        3
#define IDS_COPY                        4
#define IDS_FIND                        5
#define IDS_RECOMPILE                   6
#define IDS_DEFINES                     7
#ifdef COMPRESSOR_OPTION
#define IDS_COMPRESSOR                  8
#endif
#define IDS_TEST                        9
#define IDS_EDITSCRIPT                  10
#define IDS_BROWSESCR                   11
#define IDS_CLEARLOG                    12
#define IDS_NSISHOME                    13
#define IDS_NSISDEV                     14
#define IDS_FORUM                       15
#define IDS_NSISUPDATE                  16
#define IDS_DOCS                        17
#define IDS_DEFAULT                     18
#define IDS_ZLIB                        19
#define IDS_GZIP                        20
#define DLG_MAIN                        101
#define IDI_ICON                        102
#define DLG_ABOUT                       103
#define IDM_MENU                        104
#define IDK_ACCEL                       105
#define IDI_SHELL                       112
#define IDB_LOGO                        115
#define DLG_DEFINES                     116
#define IDB_BITMAP1                     120
#define IDB_TOOLBAR                     122
#define IDC_LOGWIN                      402
#define IDC_VERSION                     405
#define IDC_CLOSE                       406
#define IDM_ABOUT                       501
#define IDM_EXIT                        502
#define IDM_SAVE                        503
#define IDM_COPY                        504
#define IDM_COPYSELECTED                505
#define IDM_RECOMPILE                   506
#define IDM_NSISHOME                    507
#define IDC_TEST                        1000
#define IDC_ABOUTVERSION                1001
#define IDC_ABOUTCOPY                   1003
#define IDC_ABOUTPORTIONS               1005
#define IDC_CONTRIB                     1009
#define IDC_NSISVER                     1010
#define IDC_OTHERCONTRIB                1016
#define IDC_SYMBOL                      1017
#define IDC_VALUE                       1018
#define IDRIGHT                         1019
#define IDLEFT                          1020
#define IDC_DEFINES                     1021
#ifdef COMPRESSOR_OPTION
#define IDM_COMPRESSOR                  40001
#endif
#define IDM_TEST                        40002
#define IDM_EDITSCRIPT                  40003
#define IDM_DOCS                        40004
#define IDM_LOADSCRIPT                  40005
#define IDM_FIND                        40006
#define IDM_SELECTALL                   40007
#define IDM_CLEARLOG                    40009
#define IDM_BROWSESCR                   40013
#define IDM_NSISDEV                     40014
#define IDM_FORUM                       40016
#define IDM_DEFINES                     40017
#define IDM_NSISUPDATE                  40018
#define IDM_DEFAULT                     40020
#define IDM_ZLIB                        40021
#define IDM_GZIP                        40022

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        124
#define _APS_NEXT_COMMAND_VALUE         40023
#define _APS_NEXT_CONTROL_VALUE         1023
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
